@@ -1,7 +1,7 @@
 //
 //  Mixer.app
 // 
-//  Copyright (c) 1998, 1999 Per Liden
+//  Copyright (c) 1998-2002 Per Liden
 // 
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -21,8 +21,11 @@
 
 #include "Mixer.h"
 
-int main(int argc, char** argv) {
-    Mixer app(argc, argv);
-    app.run();
-    return 0;
+Mixer* app;
+
+int main(int argc, char** argv) 
+{
+   app = new Mixer(argc, argv);
+   app->run();
+   return 0;
 }
